Crate kcr_metacontroller_k8s_io

Crate kcr_metacontroller_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the metacontroller.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

metacontroller.k8s.io/v1alpha1

  • CompositeController
  • ControllerRevision
  • DecoratorController

Modules

v1alpha1